﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections.ObjectModel;
using Forum.Model;
using System.ComponentModel;
using System.Windows.Input;

namespace Forum.ViewModel
{
    public class PostViewModel : ViewModelBase, IDataErrorInfo
    {

        private Post post;

        public PostViewModel(Post post)
        {
            this.post = post;
        }

        public String Title
        {
            get { return this.post.Title ?? String.Empty; }
            set
            {
                if (this.post.Title != value)
                {
                    this.post.Title = value;
                    OnPropertyChanged("Title");
                }
            }
        }

        public String Body
        {
            get { return this.post.Body ?? String.Empty; }
            set
            {
                if (this.post.Body != value)
                {
                    this.post.Body = value;
                    OnPropertyChanged("Body");
                    OnPropertyChanged("Summary");
                }
            }
        }

        public String Author
        {
            get { return this.post.Author ?? String.Empty; }
            set
            {
                if (this.post.Author != value)
                {
                    this.post.Author = value;
                    OnPropertyChanged("Author");
                }
            }
        }

        public DateTime CreationTime
        {
            get { return this.post.CreationTime; }
            set
            {
                if (this.post.CreationTime != value)
                {
                    this.post.CreationTime = value;
                    OnPropertyChanged("CreationTime");
                }
            }
        }

        public String Summary
        {
            get
            {
                const int maxCharacters = 50;
                if (this.Body.Length > maxCharacters)
                    return this.Body.Substring(0, maxCharacters);

                return this.Body;
            }
        }


        #region IDataErrorInfo Members

        string IDataErrorInfo.Error
        {
            get
            {
                return ValidateColumn("Title") ?? ValidateColumn("Body");
            }
        }

        string IDataErrorInfo.this[string columnName]
        {
            get
            {
                string error = ValidateColumn(columnName);
                CommandManager.InvalidateRequerySuggested();

                return error;
            }
        }

        private string ValidateColumn(string columnName)
        {
            switch (columnName)
            {
                case "Title":
                    return (String.IsNullOrEmpty(this.Title)) ? "Title is empty" : null;
                case "Body":
                    return (String.IsNullOrEmpty(this.Body)) ? "Body is empty" : null;
                default:
                    return null;
            }
        }


        #endregion
    }

    public class PostViewModelCollection : ObservableCollection<PostViewModel>
    { }
}
